@@ -2,22 +2,29 @@
 
 /* Purpose: Calendar utilities */
 
-/* Copyright (C) 1995--2016 Charlie Zender
+/* Copyright (C) 1995--2017 Charlie Zender
    This file is part of NCO, the netCDF Operators. NCO is free software.
    You may redistribute and/or modify NCO under the terms of the 
    GNU General Public License (GPL) Version 3 with exceptions described in the LICENSE file */
 
 #include "nco_cln_utl.h" /* Calendar utilities */
+#include "libnco.h"
+#include "nco.h"
 
 /* Arrays to hold calendar type units */
 /* Format: year, month, day, hour, minute, second, origin, offset */
-double DATA_360[8]={31104000.0,2592000.0,86400.0,3600.0,60.0,1,0.0,0.0};
-double DATA_365[8]={31536000.0,2628000.0,86400.0,3600.0,60.0,1,0.0,0.0};
+/* origin for all calendars is 2001-01-01 (seconds)  (same as origin for udunits xalendar) */
+static double DATA_360[8]={31104000.0,2592000.0,86400.0,3600.0,60.0,1.0,31104000.0*2001.0,0.0};
+static double DATA_365[8]={31536000.0,2628000.0,86400.0,3600.0,60.0,1.0,31536000.0*2001.0,0.0};
+static double DATA_366[8]={31622400.0,2635200.0,86400.0,3600.0,60.0,1.0,63276422400.0,0.0};
 
 /* Days in months */
-int DAYS_PER_MONTH_360[12]={30,30,30,30,30,30,30,30,30,30,30,30};
-int DAYS_PER_MONTH_365[12]={31,28,31,30,31,30,31,31,30,31,30,31};
-int DAYS_PER_MONTH_366[12]={31,29,31,30,31,30,31,31,30,31,30,31};
+static int DAYS_PER_MONTH_360[12]={30,30,30,30,30,30,30,30,30,30,30,30};
+static int DAYS_PER_MONTH_365[12]={31,28,31,30,31,30,31,31,30,31,30,31};
+static int DAYS_PER_MONTH_366[12]={31,29,31,30,31,30,31,31,30,31,30,31};
+
+/* Size of temporary buffer used in parsing calendar dates */
+#define NCO_MAX_LEN_TMP_SNG 200
 
 int /* O [nbr] Number of days to end of month */
 nco_nd2endm /* [fnc] Compute number of days to end of month */
@@ -135,8 +142,7 @@ nco_newdate /* [fnc] Compute date a specified number of days from input date */
 tm_typ /* O [enm] Units type */
 nco_cln_get_tm_typ /* Returns time unit type or tm_void if not found */
 (const char *ud_sng){ /* I [ptr] Units string  */
-  int idx;
-  int len; 
+  size_t len; 
   char *lcl_sng;  
   tm_typ rcd_typ;
   
@@ -147,7 +153,7 @@ nco_cln_get_tm_typ /* Returns time unit type or tm_void if not found */
   
   /* Convert to lower case */
   len=strlen(lcl_sng);
-  for(idx=0;idx<len;idx++) lcl_sng[idx]=tolower(lcl_sng[idx]);
+  for(size_t idx=0;idx<len;idx++) lcl_sng[idx]=tolower(lcl_sng[idx]);
   
   if(!strcmp(lcl_sng,"year") || !strcmp(lcl_sng,"years")) rcd_typ=tm_year;
   else if(!strcmp(lcl_sng,"month") || !strcmp(lcl_sng,"months")) rcd_typ=tm_month;
@@ -160,9 +166,59 @@ nco_cln_get_tm_typ /* Returns time unit type or tm_void if not found */
   return rcd_typ;
 } /* end nco_cln_get_tm_typ() */
 
+
+char *                 /* O [sng] contains newly malloced output string */
+nco_cln_fmt_dt         /*   [fnc] format an output string */
+(tm_cln_sct *ttx,      /* I [ptr] Calendar structure */
+int ifmt)              /* I [enm] nco_fmt_dt */
+{
+ char bdate[200]={0};
+ char btime[200]={0};
+ char *buff;
+
+ buff=(char*)nco_malloc( sizeof(char) * NCO_MAX_LEN_FMT_SNG );
+
+ switch(ifmt)
+ {
+    /* plain format all out */
+    case fmt_dt_rgl:
+     sprintf(buff,"%04d-%02d-%02d %02d:%02d:%f", ttx->year,ttx->month, ttx->day,ttx->hour,ttx->min,ttx->sec  );
+     break;
+
+
+     /* plain format all out with 'T' char as spacer*/
+   case fmt_dt_iso8601:
+     sprintf(buff,"%04d-%02d-%02dT%02d:%02d:%f", ttx->year,ttx->month, ttx->day,ttx->hour,ttx->min,ttx->sec  );
+     break;
+
+     /* do date and time if time not all zero */
+    case fmt_dt_sht:
+    case fmt_dt_nil:
+      sprintf(bdate,"%04d-%02d-%02d", ttx->year,ttx->month, ttx->day);
+      if( ttx->hour !=0 || ttx->min!=0 || ttx->sec !=0.0 )
+      {
+        int isec;
+        double m_sec, frac_sec;
+
+        frac_sec=modf(ttx->sec, &m_sec);
+        isec=(int)m_sec;
+
+        if( frac_sec==0.0)
+          sprintf(btime, " %02d:%02d:%02d", ttx->hour,ttx->min, isec );
+        else
+          sprintf(btime, " %02d:%02d:%02.7f", ttx->hour,ttx->min, ttx->sec );
+      }
+      sprintf(buff,"%s%s", bdate,btime);
+      break;
+ }
+
+   return buff;
+}
+
+
 nco_cln_typ /* [enm] Calendar type */
 nco_cln_get_cln_typ /* [fnc] Determine calendar type or cln_nil if not found */
-(const char *ud_sng) /* I [ptr] units string  */
+(const char *ud_sng) /* I [ptr] Units string */
 {
   int idx;
   int len; 
@@ -225,6 +281,82 @@ nco_cln_days_in_year_prior_to_given_month /* [fnc] Number of days in year prior
   return idays;
 } /* end nco_cln_days_in_year_prior_to_given_month() */
 
+
+void
+nco_cln_pop_tm         /* [fnc] Calculate other members  in cln_sct from value*/
+(tm_cln_sct *cln_sct) /* I/O [ptr] Calendar structure */
+{
+  int idx;
+  int *days_per_month=NULL_CEWI;
+  long ivalue;
+  long days;
+  double fr_value;
+  double m_value;
+  double *data=NULL_CEWI;
+
+  switch(cln_sct->sc_cln)
+  {
+    case cln_360:
+      data=DATA_360;
+      days_per_month=DAYS_PER_MONTH_360;
+      break;
+
+    case cln_365:
+      data=DATA_365;
+      days_per_month=DAYS_PER_MONTH_365;
+      break;
+
+    case cln_366:
+       data=DATA_366;
+       days_per_month=DAYS_PER_MONTH_366;
+       break;
+
+    case cln_std:
+    case cln_grg:
+    case cln_jul:
+    case cln_nil:
+      break;
+  } /* end switch */
+
+
+  /* take account of origin */
+
+
+  /* get integer value and fraction part - nb add origin */
+  fr_value=modf(cln_sct->value+(double)data[6], &m_value);
+
+  ivalue=(long)m_value;
+
+  /* integer arithmetic kind of */
+  cln_sct->sec= (ivalue % 60);
+  cln_sct->sec+=fr_value;
+
+  cln_sct->min =   (ivalue % (long)data[3]) /  (long)data[4];
+  cln_sct->hour =  (ivalue % (long)data[2]) / (long)data[3];
+  cln_sct->year=  ivalue / (long)data[0];
+
+  /* days from start of year remember  zero based */
+  days= ivalue % (long)data[0] / (long)data[2];
+
+  /* remember a calendar is one based NOT zero based */
+  days+=1;
+  cln_sct->month=1;
+
+  for(idx=0 ; idx<12 ;idx++  )
+  {
+    if( days - days_per_month[idx] <=0 )
+      break;
+
+    days -= days_per_month[idx];
+      ++cln_sct->month;
+  }
+  cln_sct->day=days;
+
+
+  return;
+} /* end nco_cln_pop_tm() */
+
+
 void
 nco_cln_pop_val /* [fnc] Calculate value in cln_sct */ 
 (tm_cln_sct *cln_sct) /* I/O [ptr] structure */
@@ -240,8 +372,10 @@ nco_cln_pop_val /* [fnc] Calculate value in cln_sct */
       data[2]*(cln_sct->day-1)+
       data[3]*cln_sct->hour+
       data[4]*cln_sct->min+
-      data[5]*(double)cln_sct->sec;
-    break; 
+      data[5]*cln_sct->sec;
+      /* subtract origin */
+      cln_sct->value-=data[6];
+      break;
   case cln_365:  
     data=DATA_365;    
     cln_sct->value=data[0]*(cln_sct->year-1)+
@@ -249,20 +383,34 @@ nco_cln_pop_val /* [fnc] Calculate value in cln_sct */
       data[2]*(cln_sct->day-1)+
       data[3]*cln_sct->hour+
       data[4]*cln_sct->min+
-      data[5]*(double)cln_sct->sec;
-    break;
+      data[5]*cln_sct->sec;
+      /* subtract origin */
+      cln_sct->value-=data[6];
+      break;
   case cln_366:
-    break;
+    data=DATA_366;    
+    cln_sct->value=data[0]*(cln_sct->year-1)+
+      data[2]*nco_cln_days_in_year_prior_to_given_month(cln_366,cln_sct->month)+
+      data[2]*(cln_sct->day-1)+
+      data[3]*cln_sct->hour+
+      data[4]*cln_sct->min+
+      data[5]*cln_sct->sec;
+      /* subtract origin */
+      cln_sct->value-=data[6];
+      break;
   case cln_std:
   case cln_grg:
   case cln_jul:
   case cln_nil:
-    break;
+      break;
   } /* end switch */
   
   return;
 } /* end nco_cln_pop_val() */
 
+
+
+
 double /* O [dbl] time in (base) seconds of tm_typ */
 nco_cln_val_tm_typ
 ( nco_cln_typ lmt_cln, /* I [enm] Calendar type */ 
@@ -279,6 +427,7 @@ nco_cln_val_tm_typ
     data=DATA_365;    
     break;
   case cln_366:
+    data=DATA_366;    
     break;
   case cln_std:
   case cln_grg:
@@ -314,6 +463,17 @@ nco_cln_val_tm_typ
 } /* end nco_cln_typ_val() */
 
 
+void
+nco_cln_prn_tm         /* [fnc] print tm sct*/
+(tm_cln_sct *cln_sct) /* I [ptr] Calendar structure */
+{
+
+  (void)fprintf(stderr ,"%s: tm_sct cln_type=%d date=\"%d-%d-%d %d:%d:%g\" value=%g\n", nco_prg_nm_get(),cln_sct->sc_cln,
+              cln_sct->year, cln_sct->month, cln_sct->day,cln_sct->hour,cln_sct->min, cln_sct->sec,cln_sct->value );
+
+   return;
+}
+
 int /* O [flg] String is calendar date */
 nco_cln_chk_tm /* [fnc] Is string a UDUnits-compatible calendar format, e.g., "PERIOD since REFERENCE_DATE" */
 (const char *unit_sng) /* I [sng] Units string */
@@ -334,11 +494,13 @@ nco_cln_clc_dbl_var_dff( /* [fnc] difference between two co-ordinate units */
 const char *fl_unt_sng, /* I [ptr] units attribute string from disk */
 const char *fl_bs_sng,  /* I [ptr] units attribute string from disk */
 nco_cln_typ lmt_cln,    /* I [enum] Calendar type of coordinate var */ 
-double *dval,           /* I/O [dbl] var values modified */
+double *val_dbl,         /* I/O [dbl] var values modified */
 var_sct *var)           /* I/O [var_sct] var values modified */
 {
+  (void)fprintf(stderr,"%s: WARNING NCO was built without UDUnits. NCO is therefore unable to convert values from \"%s\" to \"%s\". See http://nco.sf.net/nco.html#rbs for more information.\n%s: HINT Re-build or re-install NCO enabled with UDUnits.\n",nco_prg_nm_get(),fl_unt_sng,fl_bs_sng,nco_prg_nm_get());
+
   return NCO_NOERR;
-}
+} /* end nco_cln_clc_dbl_var_dff() */
 
 int /* [flg] NCO_NOERR or NCO_ERR */ 
 nco_cln_clc_dbl_org(   /* [fnc] difference between two co-ordinate units */
@@ -348,8 +510,9 @@ nco_cln_typ lmt_cln,    /* I [enum] Calendar type of coordinate var */
 double *og_val)         /* O [dbl] output value */
 {
   *og_val=0.0; /* CEWI */
+  (void)fprintf(stderr,"%s: WARNING NCO was built without UDUnits. NCO is therefore unable to interpret the string \"%s\" limit argument.\n%s: HINT Re-build or re-install NCO enabled with UDUnits.\n",nco_prg_nm_get(),val_unt_sng,nco_prg_nm_get());
   return NCO_NOERR; 
-}
+} /* !nco_cln_clc_dbl_org() */
 
 int /* [rcd] Return code */
 nco_cln_sng_rbs /* [fnc] Rebase calendar string for legibility */
@@ -362,7 +525,18 @@ nco_cln_sng_rbs /* [fnc] Rebase calendar string for legibility */
   lgb_sng[0]='\0'; /* CEWI */
   return NCO_NOERR;
 } /* end nco_cln_sng_rbs() */
-  
+
+int
+nco_cln_var_prs
+(const char *fl_unt_sng,
+ nco_cln_typ lmt_cln,
+ int ifmt,
+ var_sct *var,
+ var_sct *var_ret)
+{
+  return NCO_ERR;
+} /*  !nco_cln_var_prs() */
+
 #endif /* !ENABLE_UDUNITS */
 
 #ifdef ENABLE_UDUNITS
@@ -374,7 +548,7 @@ nco_cln_cnv_mk  /* [fnc] UDUnits2 create a custom converter  */
 (const char *fl_unt_sng, /* I [ptr] units attribute string from disk */
  const char *fl_bs_sng) /* I [ptr] units attribute string from disk */
 {
-  const char fnc_nm[]="nco_cln_cnv_mk"; /* [sng] Function name */
+  const char fnc_nm[]="nco_cln_cnv_mk()"; /* [sng] Function name */
   
   cv_converter *ut_cnv; /* UDUnits converter */
 
@@ -428,159 +602,122 @@ nco_cln_cnv_mk  /* [fnc] UDUnits2 create a custom converter  */
   ut_free_system(ut_sys); /* Free memory taken by UDUnits library */
   // cv_free(ut_cnv);
 
-
   return ut_cnv;
 }  /* end UDUnits2 nco_cln_cnv_mk() */
 
-
-int    /* [flg] NCO_NOERR or NCO_ERR */ 
+int /* [flg] NCO_NOERR or NCO_ERR */ 
 nco_cln_clc_dbl_dff( /* [fnc] difference between two co-ordinate units */
 const char *fl_unt_sng, /* I [ptr] units attribute string from disk */
-const char *fl_bs_sng,  /* I [ptr] units attribute string from disk */
+const char *fl_bs_sng, /* I [ptr] units attribute string from disk */
 double *og_val)
-{           /* I/O [dbl] var values modified */
-
+{ /* I/O [dbl] var values modified */
   cv_converter *ut_cnv=NULL; 
-  const char fnc_nm[]="nco_cln_clc_var_dff()"; /* [sng] Function name */
-  
-  
-  /* do nothing if units identical */
-  if(strcasecmp(fl_unt_sng,fl_bs_sng)==0)
-    return NCO_NOERR;
+
+  /* Do nothing if units identical */
+  if(strcasecmp(fl_unt_sng,fl_bs_sng)==0) return NCO_NOERR;
 
   /* Convert */
   ut_cnv=nco_cln_cnv_mk(fl_unt_sng, fl_bs_sng);
 
-  if(ut_cnv != NULL)
-     og_val[0]=cv_convert_double(ut_cnv,og_val[0]);                      
-  else
-     return NCO_ERR;     
+  if(ut_cnv != NULL) og_val[0]=cv_convert_double(ut_cnv,og_val[0]); else return NCO_ERR;     
 
- cv_free(ut_cnv);  
+  cv_free(ut_cnv);  
 
- return NCO_NOERR;          
-}  
+  return NCO_NOERR;          
+} /* end UDUnits2 nco_cln_clc_dbl_dff() */
 
+int /* [flg] NCO_NOERR or NCO_ERR */ 
+nco_cln_clc_var_dff /* [fnc] difference between two co-ordinate units */
+(const char *fl_unt_sng, /* I [ptr] units attribute string from disk */
+ const char *fl_bs_sng, /* I [ptr] units attribute string from disk */
+ var_sct *var) /* I/O [dbl] var values modified */
+{
+  cv_converter *ut_cnv=NULL; 
 
-int    /* [flg] NCO_NOERR or NCO_ERR */ 
-nco_cln_clc_var_dff( /* [fnc] difference between two co-ordinate units */
-const char *fl_unt_sng, /* I [ptr] units attribute string from disk */
-const char *fl_bs_sng,  /* I [ptr] units attribute string from disk */
-var_sct *var)
-{           /* I/O [dbl] var values modified */
-
-  size_t sz;
-  size_t idx;    
-  double *dp;  
   ptr_unn op1;    
 
-  cv_converter *ut_cnv=NULL; 
-  const char fnc_nm[]="nco_cln_clc_var_dff()"; /* [sng] Function name */
+  size_t idx;    
+
+  size_t sz;
   
-  
-  /* do nothing if units identical */
-  if(strcasecmp(fl_unt_sng,fl_bs_sng)==0)
-    return NCO_NOERR;
+  /* Do nothing if units identical */
+  if(!strcasecmp(fl_unt_sng,fl_bs_sng)) return NCO_NOERR;
 
   /* Convert */
-  ut_cnv=nco_cln_cnv_mk(fl_unt_sng, fl_bs_sng);
+  ut_cnv=nco_cln_cnv_mk(fl_unt_sng,fl_bs_sng);
 
-  if(ut_cnv == NULL)
-      return NCO_ERR;     
+  if(ut_cnv == NULL) return NCO_ERR;     
 
   sz=var->sz;  
 
   (void)cast_void_nctype(var->type,&op1);                
   op1=var->val;
  
-  if(var->type==NC_DOUBLE)
-  {
-
+  if(var->type == NC_DOUBLE){
     double *dp;
     dp=op1.dp;     
 
-  if(var->has_mss_val)
-  {
+    if(var->has_mss_val){
       double mss_dbl=var->mss_val.dp[0]; 
       for(idx=0; idx<sz; idx++)
-	if( dp[idx] != mss_dbl)   
+	if(dp[idx] != mss_dbl)
 	  dp[idx]=cv_convert_double(ut_cnv,dp[idx]);                      
-  }else
+    }else{
      (void)cv_convert_doubles(ut_cnv,dp,sz,dp);                      
-  
-
-  }
-
-  else if(var->type==NC_FLOAT)
-  {
-
+    } /* !has_mss_val */
+  }else if(var->type==NC_FLOAT){
     float*fp;
     fp=op1.fp;     
-
-  if(var->has_mss_val)
-  {
+    if(var->has_mss_val){
       float mss_fp=var->mss_val.fp[0]; 
-      for(idx=0; idx<sz; idx++)
-	if( fp[idx] != mss_fp)   
+      for(idx=0;idx<sz;idx++)
+	if(fp[idx] != mss_fp)   
 	  fp[idx]=cv_convert_float(ut_cnv,fp[idx]);                      
-  }
-  else
-    (void)cv_convert_floats(ut_cnv,fp,sz,fp);                      
-  
-
-  }
-
+    }else{
+      (void)cv_convert_floats(ut_cnv,fp,sz,fp);                      
+    } /* !has_mss_val */
+  } /* !var->type */
 
  cv_free(ut_cnv);  
  (void)cast_nctype_void(var->type,&op1);
 
  return NCO_NOERR;
-                
-}  
+} /* !nco_cln_clc_var_dff() */
 
-
-int    /* [flg] NCO_NOERR or NCO_ERR */ 
+int /* [flg] NCO_NOERR or NCO_ERR */ 
 nco_cln_clc_dbl_var_dff( /* [fnc] difference between two co-ordinate units */
 const char *fl_unt_sng, /* I [ptr] units attribute string from disk */
 const char *fl_bs_sng,  /* I [ptr] units attribute string from disk */
 nco_cln_typ lmt_cln,    /* I [enum] Calendar type of coordinate var */ 
 double *og_val,           /* I/O [dbl] var values modified -can be NULL */
-var_sct *var)           /* I/O [var_sct] var values modified - can be NULL  */
-{
-  int rcd;
+var_sct *var) /* I/O [var_sct] var values modified - can be NULL  */
+{ /* Purpose: */
+  
+  const char fnc_nm[]="nco_cln_clc_dbl_var_dff()"; /* [sng] Function name */
+
   int is_date;
-  const char fnc_nm[]="nco_cln_clc_dv_dff()"; /* [sng] Function name */
+  int rcd;
 
-  if(nco_dbg_lvl_get() >= nco_dbg_scl) 
-     (void)fprintf(stderr,"%s: nco_cln_clc_dbl_var_dff() reports unt_sng=%s bs_sng=%s calendar=%d\n",nco_prg_nm_get(),fl_unt_sng,fl_bs_sng,lmt_cln);
+  if(nco_dbg_lvl_get() >= nco_dbg_crr) (void)fprintf(stderr,"%s: %s reports unt_sng=%s bs_sng=%s calendar=%d\n",nco_prg_nm_get(),fnc_nm,fl_unt_sng,fl_bs_sng,lmt_cln);
 
+  /* Do nothing if units identical */
+  if(!strcasecmp(fl_unt_sng,fl_bs_sng)) return NCO_NOERR;
 
-  
-  /* do nothing if units identical */
-  if(!strcasecmp(fl_unt_sng,fl_bs_sng))
-    return NCO_NOERR;
-
-
-  /* see if target units is of the form  "units since date-string" */
-  is_date = nco_cln_chk_tm(fl_bs_sng);
-
-  /* use custom time functions if irregular calendar */
-  if(is_date && (lmt_cln==cln_360 || lmt_cln==cln_365) )
-    rcd=nco_cln_clc_tm( fl_unt_sng, fl_bs_sng,lmt_cln, og_val, var);  
-
-  else if(og_val != (double*)NULL) 
-     rcd=nco_cln_clc_dbl_dff(fl_unt_sng, fl_bs_sng,og_val);  
-
-  else if(var != (var_sct*)NULL)
-    rcd=nco_cln_clc_var_dff(fl_unt_sng, fl_bs_sng,var);
-
-  
+  /* Are target units of the form  "units since date-string" */
+  is_date=nco_cln_chk_tm(fl_bs_sng);
 
+  /* Use custom time functions if irregular calendar */
+  if(is_date && (lmt_cln == cln_360 || lmt_cln == cln_365 || lmt_cln == cln_366))
+    rcd=nco_cln_clc_tm(fl_unt_sng,fl_bs_sng,lmt_cln,og_val,var);  
+  else if(og_val != (double *)NULL) 
+    rcd=nco_cln_clc_dbl_dff(fl_unt_sng,fl_bs_sng,og_val);
+  else if(var != (var_sct *)NULL)
+    rcd=nco_cln_clc_var_dff(fl_unt_sng,fl_bs_sng,var);
+  else
+    rcd=NCO_NOERR;
+    
   return rcd;
-
-}  /* end UDUnits2 nco_cln_clc_dff() */
-
-
+} /* end UDUnits2 nco_cln_clc_dbl_var_dff() */
 
 int   /* [flg] NCO_NOERR or NCO_ERR */ 
 nco_cln_clc_dbl_org(   /* [fnc] difference between two co-ordinate units */
@@ -589,83 +726,70 @@ const char *fl_bs_sng,  /* I [ptr] units attribute string from disk */
 nco_cln_typ lmt_cln,    /* I [enum] Calendar type of coordinate var */ 
 double *og_val)         /* O [dbl] output value */
 {
-  int is_date;  /* set to true if date/time unit */
-  int rcd;
-  int month;
-  int year;
+  const char fnc_nm[]="nco_cln_clc_dbl_org()"; /* [sng] Function name */
 
-  char lcl_unt_sng[200];
-  const char fnc_nm[]="nco_cln_dbl_org"; /* [sng] Function name */
-  
-  double dval;
+  int is_date=0;  /* set to true if date/time unit */
+  int rcd=0;
+  int month=0;
+  int year=0;
+  char lcl_unt_sng[200]={0};
+  double val_dbl=0.0;
 
   rcd=0;  
 
-  dval=0.0;
+  val_dbl=0.0;
 
-  is_date = nco_cln_chk_tm(fl_bs_sng);
+  is_date=nco_cln_chk_tm(fl_bs_sng);
 
   lcl_unt_sng[0]='\0';
   
-  if(nco_dbg_lvl_get() >= nco_dbg_vrb) 
-       (void)fprintf(stderr,"%s: INFO %s: reports unt_sng=%s bs_sng=%s calendar=%d\n",nco_prg_nm_get(),fnc_nm,val_unt_sng,fl_bs_sng,lmt_cln);
+  if(nco_dbg_lvl_get() >= nco_dbg_vrb) (void)fprintf(stderr,"%s: INFO %s: reports unt_sng=%s bs_sng=%s calendar=%d\n",nco_prg_nm_get(),fnc_nm,val_unt_sng,fl_bs_sng,lmt_cln);
 
-  
-    /* Does fl_unt_sng look like a regular timestamp? */ 
-  if(is_date && sscanf(val_unt_sng,"%d-%d",&year,&month) == 2)
-  {
-    /* udunits requires  this prefix that it can recognize a raw-datetime string */  
+  /* Does fl_unt_sng look like a regular timestamp? */ 
+  if(is_date && sscanf(val_unt_sng,"%d-%d",&year,&month) == 2){
+    /* UDUnits requires this prefix to recognize a raw-datetime string */  
     strcpy(lcl_unt_sng,"s@");
     strcat(lcl_unt_sng,val_unt_sng);
-  }
-  else
-  {
+    val_dbl=0.0;
+  }else{
     /* Regular conversion of fl_unt_sng of form <double_value units>, e.g., '10 inches', '100 ft'  '10 days since 1970-01-01' */
-    char *ptr=(char*)NULL;
+    char *ptr=NULL;
         
-    dval=strtod(val_unt_sng, &ptr);  
-        
-    if(ptr==val_unt_sng || strlen(++ptr)<1)
-    {
+    val_dbl=strtod(val_unt_sng,&ptr);  
+    if(ptr == val_unt_sng || strlen(++ptr) < 1L){
       (void)fprintf(stderr, "%s: INFO %s() reports input string must be of the form \"value unit\" got the string \"%s\"\n",nco_prg_nm_get(),fnc_nm,val_unt_sng);
       nco_exit(EXIT_FAILURE);           
-    }
+    } /* !ptr */
     strcpy(lcl_unt_sng,ptr); 
-  }
+  } /* !is_date */
 
-  /* use custom time functions if irregular calendar */
-  if(is_date && (lmt_cln==cln_360 || lmt_cln==cln_365) )
-    rcd=nco_cln_clc_tm( lcl_unt_sng, fl_bs_sng,lmt_cln,&dval, (var_sct*)NULL);  
-  else
-    rcd=nco_cln_clc_dbl_dff(lcl_unt_sng, fl_bs_sng,&dval);     
-	       	     
+  /* Use custom time functions if irregular calendar */
+  if(is_date && (lmt_cln == cln_360 || lmt_cln == cln_365 || lmt_cln == cln_366)){
+    rcd=nco_cln_clc_tm(lcl_unt_sng,fl_bs_sng,lmt_cln,&val_dbl,(var_sct *)NULL);
+  }else rcd=nco_cln_clc_dbl_dff(lcl_unt_sng,fl_bs_sng,&val_dbl);
 
-  /* only copy over if successfull */ 
-  if(rcd==NCO_NOERR)
-     *og_val=dval;
-    
+  /* Copy over iff successful */ 
+  if(rcd==NCO_NOERR) *og_val=val_dbl; else (void)fprintf(stderr,"%s: ERROR %s: report unt_sng=%s bs_sng=%s calendar=%d og_val=%f\n",nco_prg_nm_get(),fnc_nm,val_unt_sng,fl_bs_sng,lmt_cln, val_dbl);  
+ 
   return rcd;        
-}
+} /* !nco_cln_clc_dbl_org() */
 
-/* This function is only called if the target units in fl_bs_sng of the form "value unit since date-stamp" 
-   and the calendar type is cln_360 or cln_365.
-   either "var" is NULL and there is a single value to process *og_val 
-   or var is initialized and  og_val is NULL  */
 int /* [rcd] Successful conversion returns NCO_NOERR */
 nco_cln_clc_tm /* [fnc] Difference between two coordinate units */
 (const char *fl_unt_sng, /* I [ptr] Units attribute string from disk */
  const char *fl_bs_sng, /* I [ptr] Units attribute string from disk */
  nco_cln_typ lmt_cln, /* [enum] Calendar type of coordinate variable */ 
  double *og_val, /* I/O [ptr] */
- var_sct *var){  /* I/O [ptr] */  
-  int rcd;
-  int year;
-  int month;
-  char *lcl_unt_sng;
-  /* 20141230 figure out better length */
-  char tmp_sng[100];
-  double crr_val;
-  double scl_val;
+ var_sct *var) /* I/O [ptr] */  
+{
+  /* Called for target units in fl_bs_sng of form "value unit since date-stamp" for cln_360 or cln_365
+     Either "var" is NULL and there is a single value to process *og_val or var is initialized and og_val is NULL */
+  const char fnc_nm[]="nco_cln_clc_tm()"; /* [sng] Function name */
+
+  char *tmp_sng;
+
+  double crr_val=0.0;
+  double scl_val=1.0;
 
   tm_typ unt_tm_typ; /* enum for units type in fl_unt_sng */  
   tm_typ bs_tm_typ; /* enum for units type in fl_bs_sng */
@@ -673,25 +797,25 @@ nco_cln_clc_tm /* [fnc] Difference between two coordinate units */
   tm_cln_sct unt_cln_sct;
   tm_cln_sct bs_cln_sct;
   
-  if(nco_dbg_lvl_get() >= nco_dbg_scl) 
-     (void)fprintf(stderr,"%s: nco_cln_clc_tm() reports unt_sng=%s bs_sng=%s\n",nco_prg_nm_get(),fl_unt_sng,fl_bs_sng);
-
-  /* blow out if bad cln type */
-  if(lmt_cln != cln_360 &&  lmt_cln != cln_365)
-  {
-    (void)fprintf(stderr,"%s: nco_cln_clc_tm() has been called with wrong calander types - only cln_365 and cln_360 allowed\n",nco_prg_nm_get());
-    nco_exit(EXIT_FAILURE); 
-  }       
-  
+  /* Die if unsupported calendar type */
+  if(lmt_cln != cln_360 && lmt_cln != cln_365 && lmt_cln != cln_366){
+    (void)fprintf(stderr,"%s: %s reports invalid calendar type lmt_cln=%d. Only cln_365,cln_360 cln_366 allowed.\n",nco_prg_nm_get(),fnc_nm,lmt_cln);
+    nco_exit(EXIT_FAILURE);
+  } /* !lmt_cln */
 
   /* Obtain units type from fl_bs_sng */
+  tmp_sng=(char *)nco_calloc(NCO_MAX_LEN_TMP_SNG,sizeof(char));
   if(sscanf(fl_bs_sng,"%s",tmp_sng) != 1) return NCO_ERR;
-    bs_tm_typ=nco_cln_get_tm_typ(tmp_sng);  
-
-  /* Obtain units type from fl_bs_sng */
-  if(sscanf(fl_unt_sng,"%s",tmp_sng) != 1) return NCO_ERR;
-    unt_tm_typ=nco_cln_get_tm_typ(tmp_sng);  
+  bs_tm_typ=nco_cln_get_tm_typ(tmp_sng);  
+  if(nco_dbg_lvl_get() >= nco_dbg_crr) (void)fprintf(stderr,"%s: %s reports unt_sng=\"%s\", bs_sng=\"%s\", tmp_sng=\"%s\"\n",nco_prg_nm_get(),fnc_nm,fl_unt_sng,fl_bs_sng,tmp_sng);
+  if(tmp_sng) tmp_sng=(char *)nco_free(tmp_sng);
 
+  /* Is unit string a bare date string? */ 
+  tmp_sng=(char *)nco_calloc(NCO_MAX_LEN_TMP_SNG,sizeof(char));
+  if(!strncmp("s@",fl_unt_sng,2)) unt_tm_typ=bs_tm_typ;
+  else if(sscanf(fl_unt_sng,"%s",tmp_sng) == 1) unt_tm_typ=nco_cln_get_tm_typ(tmp_sng);  
+  else return NCO_ERR;
+  if(tmp_sng) tmp_sng=(char *)nco_free(tmp_sng);
   
   /* Assume non-standard calendar */ 
   if(nco_cln_prs_tm(fl_unt_sng,&unt_cln_sct) == NCO_ERR) return NCO_ERR;
@@ -705,69 +829,59 @@ nco_cln_clc_tm /* [fnc] Difference between two coordinate units */
   (void)nco_cln_pop_val(&unt_cln_sct);
   (void)nco_cln_pop_val(&bs_cln_sct);
   
-  /* get offset */
-  crr_val= (unt_cln_sct.value-bs_cln_sct.value) /  nco_cln_val_tm_typ(lmt_cln,bs_tm_typ);                 
+  /* Get offset */
+  crr_val=(unt_cln_sct.value-bs_cln_sct.value)/nco_cln_val_tm_typ(lmt_cln,bs_tm_typ);                 
 
-  /* scale factor */
-  if( unt_tm_typ== bs_tm_typ)
-    scl_val=1.0;
-  else
-    scl_val=nco_cln_val_tm_typ(lmt_cln,unt_tm_typ) / nco_cln_val_tm_typ(lmt_cln,bs_tm_typ);                   ;                    
+  /* Scale factor */
+  if(unt_tm_typ == bs_tm_typ) scl_val=1.0; else scl_val=nco_cln_val_tm_typ(lmt_cln,unt_tm_typ)/nco_cln_val_tm_typ(lmt_cln,bs_tm_typ);
   
-  if(og_val)
-  {   
-    *og_val=*og_val*scl_val+crr_val;     
+  if(nco_dbg_lvl_get() >= nco_dbg_crr){
+    nco_cln_prn_tm(&unt_cln_sct);
+    nco_cln_prn_tm(&bs_cln_sct);
+    (void)fprintf(stderr,"%s: %s reports offset=%g, scale factor=%g unt_val=%f bs_val=%f\n",nco_prg_nm_get(),fnc_nm,crr_val,scl_val, unt_cln_sct.value, bs_cln_sct.value);
+    if(og_val) (void)fprintf(stderr,", *og_val=%g",*og_val);
+    (void)fprintf(stderr,"\n");
+  } /* !dbg */
 
-  }
-  else if(var)
-  {
+  if(og_val){
+    *og_val=(*og_val)*scl_val+crr_val;
+  }else if(var){
     size_t sz;
     size_t idx;
-    ptr_unn op1;    
+    ptr_unn op1;
     
     sz=var->sz;  
     op1=var->val;
     (void)cast_void_nctype(var->type,&op1);
 
-    if(var->type == NC_DOUBLE)
-    {
+    if(var->type == NC_DOUBLE){
       double *dp;
-      dp=op1.dp;   
-
-      if(var->has_mss_val)
-      {  
+      dp=op1.dp;
+      if(var->has_mss_val){  
 	double mss_dbl=var->mss_val.dp[0]; 
-	for(idx=0; idx<sz; idx++)
-	  if( dp[idx] != mss_dbl) 
-	    dp[idx]= dp[idx]*scl_val+crr_val; 
-      } 
-      else
-	for(idx=0; idx<sz; idx++) 
-          dp[idx]= dp[idx]*scl_val+crr_val; 
-    }
+	for(idx=0;idx<sz;idx++)
+	  if(dp[idx] != mss_dbl) dp[idx]=dp[idx]*scl_val+crr_val; 
+      }else{
+	for(idx=0;idx<sz;idx++) dp[idx]=dp[idx]*scl_val+crr_val; 
+      } /* !var->has_mss_val */
+    } /* !NC_DOUBLE */
 
-    if(var->type == NC_FLOAT)
-    {
+    if(var->type == NC_FLOAT){
       float *fp;
-      fp=op1.fp;   
-
-      if(var->has_mss_val)
-      {  
-	float mss_ft=var->mss_val.fp[0]; 
-	for(idx=0; idx<sz; idx++)
-	   if( fp[idx] != mss_ft) fp[idx]=fp[idx]*scl_val+crr_val;                      
-      } 
-      else
-	for(idx=0; idx<sz; idx++)
-	  fp[idx]=fp[idx]*scl_val+crr_val;                      
-    }
-
+      fp=op1.fp;
+      if(var->has_mss_val){  
+	float mss_flt=var->mss_val.fp[0]; 
+	for(idx=0;idx<sz;idx++)
+	  if(fp[idx] != mss_flt) fp[idx]=fp[idx]*(float)scl_val+(float)crr_val;                      
+      }else{
+	for(idx=0;idx<sz;idx++) fp[idx]=fp[idx]*(float)scl_val+(float)crr_val;                      
+      } /* !has_mss_val */
+    } /* !NC_FLOAT */
    (void)cast_nctype_void(var->type,&op1);
-
-  }
-  lcl_unt_sng=(char *)nco_free(lcl_unt_sng);
+  } /* !var */
   
   return NCO_NOERR;
+
 } /* end nco_cln_clc_tm() */
 
 int /* [rcd] Successful conversion returns NCO_NOERR */
@@ -777,16 +891,42 @@ nco_cln_prs_tm /* UDUnits2 Extract time stamp from parsed UDUnits string */
 {
   const char fnc_nm[]="nco_cln_prs_tm()"; /* [sng] Function name */
 
-  /* 20141230: fxm figure out a better length */
-  char bfr[200];
-
-  char *dt_sng;
-
+  char *bfr;
+  char *dt_sng=NULL;
+  int cnv_nbr;
   int ut_rcd; /* [enm] UDUnits2 status */
-
+  int year;
+  int month;
+  int day;
   ut_system *ut_sys;
   ut_unit *ut_sct_in; /* UDUnits structure, input units */
 
+  bfr=(char *)nco_calloc(NCO_MAX_LEN_TMP_SNG,sizeof(char));
+
+
+
+
+  /* There is a problem letting udunits do the parsing for the other calendars - that is when parsing non regular dates
+     eg for "all_leap" (cln_366) we have dates like 2001-02-29  which cannot be meaningfully parsed by udunits
+     e.g for 360_days (cln_360)  we have dates like 1903-2-29, 1903-2-30  so we need to parse the date portion of the string here*/
+
+
+   strcpy(bfr,unt_sng); 
+    
+   if( (dt_sng=strstr(bfr,"since")))
+    dt_sng+=5;
+   else if ( (dt_sng=strstr(bfr,"from")))
+    dt_sng+=4;
+   else if ( (dt_sng=strstr(bfr,"after")))
+    dt_sng+=5;
+   else if (( dt_sng=strstr(bfr,"s@")))
+    dt_sng+=2;
+
+   if(!dt_sng) return NCO_ERR;
+
+   cnv_nbr=sscanf(dt_sng,"%d-%d-%d",&tm_in->year,&tm_in->month,&tm_in->day);
+   if(nco_dbg_lvl_get() >= nco_dbg_crr) (void)fprintf(stderr,"%s: INFO %s reports sscanf() converted %d values and it should have converted 3 values, format string=\"%s\"\n",nco_prg_nm_get(),fnc_nm,cnv_nbr,dt_sng);
+
   /* When empty, ut_read_xml() uses environment variable UDUNITS2_XML_PATH, if any
      Otherwise it uses default initial location hardcoded when library was built */
   if(nco_dbg_lvl_get() >= nco_dbg_vrb) ut_set_error_message_handler(ut_write_to_stderr); else ut_set_error_message_handler(ut_ignore);
@@ -800,23 +940,39 @@ nco_cln_prs_tm /* UDUnits2 Extract time stamp from parsed UDUnits string */
   ut_sct_in=ut_parse(ut_sys,unt_sng,UT_ASCII); 
   if(ut_sct_in == NULL){ /* Problem with 'units' attribute */
     ut_rcd=ut_get_status(); /* [enm] UDUnits2 status */
-    if(ut_rcd == UT_BAD_ARG) (void)fprintf(stderr,"ERROR: empty units attribute string\n");
-    if(ut_rcd == UT_SYNTAX)  (void)fprintf(stderr,"ERROR: units attribute \"%s\" has a syntax error\n",unt_sng);
-    if(ut_rcd == UT_UNKNOWN) (void)fprintf(stderr,"ERROR: units attribute \"%s\" is not listed in UDUnits2 SI system database\n",unt_sng);
+    if(ut_rcd == UT_BAD_ARG) (void)fprintf(stderr,"%s: ERROR %s reports empty units attribute string\n",nco_prg_nm_get(),fnc_nm);
+    else if(ut_rcd == UT_SYNTAX)  (void)fprintf(stderr,"%s: ERROR %s reports units attribute \"%s\" has a syntax error\n",nco_prg_nm_get(),fnc_nm,unt_sng);
+    else if(ut_rcd == UT_UNKNOWN) (void)fprintf(stderr,"%s: ERROR %s reports units attribute \"%s\" is not listed in UDUnits2 SI system database\n",nco_prg_nm_get(),fnc_nm,unt_sng);
+    else (void)fprintf(stderr,"%s: ERROR %s reports ut_rcd = %d\n",nco_prg_nm_get(),fnc_nm,ut_rcd);
 
     return NCO_ERR; /* Failure */
   } /* endif coordinate on disk has no units attribute */
 
   /* Print timestamp to buffer in standard, dependable format */
-  ut_format(ut_sct_in,bfr,sizeof(bfr),UT_ASCII|UT_NAMES);
+  ut_format(ut_sct_in,bfr,NCO_MAX_LEN_TMP_SNG,UT_ASCII|UT_NAMES);
 
-  /* Extract parsed time units from print string (kludgy)
-     20141230 change to using ut_decode_time() instead? */
-  dt_sng=strstr(bfr,"since");  
-  sscanf(dt_sng,"%*s %d-%d-%d %d:%d:%f",&tm_in->year,&tm_in->month,&tm_in->day,&tm_in->hour,&tm_in->min,&tm_in->sec);
+  /* ut_format string normally ends in the string UTC we wish to terminate the string before this so that sscanf doesnt get confused */
+  dt_sng=strstr(bfr,"UTC");
+  if(dt_sng) *dt_sng='\0';
 
-  ut_free_system(ut_sys); /* Free memory taken by UDUnits library */
+  dt_sng=strstr(bfr,"since");
+  dt_sng+=(size_t)6;
+  /* nb we dont need yar,month,day as that have been parsed earlier in THIS function */
+  cnv_nbr=sscanf(dt_sng,"%d-%d-%d %d:%d:%lf",&year,&month,&day,&tm_in->hour,&tm_in->min,&tm_in->sec);
+  
+  /* Set defaults */ 
+  if(cnv_nbr < 6) tm_in->sec=0.0;
+  if(cnv_nbr < 5) tm_in->min=0;   
+  if(cnv_nbr < 4) tm_in->hour=0;   
+
+  if(nco_dbg_lvl_get() >= nco_dbg_crr) (void)fprintf(stderr,"%s: INFO %s reports sscanf() converted %d values and it should have converted 6 values, format string=\"%s\"\n",nco_prg_nm_get(),fnc_nm,cnv_nbr,bfr);
+
+  bfr=(char *)nco_free(bfr);  
   ut_free(ut_sct_in);
+  ut_free_system(ut_sys); /* Free memory taken by UDUnits library */
+
+  /* Return if sscanf() messed up */
+  if(cnv_nbr < 3) return NCO_ERR;
 
   return NCO_NOERR;
 } /* end UDUnits2 nco_cln_prs_tm() */
@@ -894,6 +1050,135 @@ nco_cln_sng_rbs /* [fnc] Rebase calendar string for legibility */
 
 } /* end nco_cln_sng_rbs() */
 
+
+int
+nco_cln_var_prs
+(const char *fl_unt_sng,
+ nco_cln_typ lmt_cln,
+ int ifmt,
+ var_sct *var,
+ var_sct *var_ret
+)
+{
+  size_t sz;
+  size_t idx;
+  char empty_sng[1];
+
+  double resolution;
+  tm_cln_sct tm;
+
+
+
+  /* base units for udunits */
+  const char *bs_sng="seconds since 2001-01-01";
+  const char *fnc_nm="nco_cln_var_prs";
+  empty_sng[0]='\0';
+
+  // if( lmt_cln != cln_std )
+  //   return NCO_ERR;
+  if(var->type !=NC_DOUBLE && var->type!=NC_FLOAT)
+    nco_var_cnf_typ(NC_DOUBLE,var);
+
+  if(nco_dbg_lvl_get() >= nco_dbg_crr)
+     (void)fprintf(stderr,"%s: %s reports unt_sng=%s bs_sng=%s calendar=%d\n",nco_prg_nm_get(),fnc_nm,fl_unt_sng,bs_sng,lmt_cln);
+
+  /* rebase to seconds since blah-blah */
+  if(nco_cln_clc_dbl_var_dff(fl_unt_sng,bs_sng,lmt_cln, (double*)NULL, var ) != NCO_NOERR )
+     return NCO_ERR;
+
+
+
+  cast_void_nctype(var->type,&var->val);
+
+  if(var_ret->type !=NC_STRING)
+      nco_var_cnf_typ(NC_STRING, var_ret);
+
+  if( var_ret->val.vp)
+      var_ret->val.vp=(void*)nco_free(var_ret->val.vp);
+
+  var_ret->val.vp=nco_malloc( sizeof(nco_string) *var_ret->sz);
+
+
+  var_ret->has_mss_val=True;
+  var_ret->mss_val.vp=nco_malloc(sizeof(nco_string*));
+
+  cast_void_nctype(var_ret->type,&var_ret->val);
+
+  var_ret->mss_val.sngp[0]=strdup(empty_sng);
+
+
+  sz=var->sz;
+
+  tm.sc_cln=lmt_cln;
+
+
+  // (void)fprintf(stderr,"%s: %s reports var \"%s\" has missing value %d\n",nco_prg_nm_get(),fnc_nm,var->nm,var->has_mss_val);
+
+
+
+  if(var->type == NC_DOUBLE) {
+    double mss_val_dbl;
+    if(var->has_mss_val)
+       mss_val_dbl=var->mss_val.dp[0];
+
+    for (idx = 0; idx < sz; idx++) {
+
+
+      if(var->has_mss_val && var->val.dp[idx]==mss_val_dbl) {
+        var_ret->val.sngp[idx] = strdup(empty_sng);
+        continue;
+      }
+
+      tm.value = var->val.dp[idx];
+
+      if (lmt_cln == cln_360 || lmt_cln == cln_365 || lmt_cln == cln_366)
+        nco_cln_pop_tm(&tm);
+      else
+        (void) ut_decode_time(tm.value, &tm.year, &tm.month, &tm.day, &tm.hour, &tm.min, &tm.sec, &resolution);
+
+      var_ret->val.sngp[idx] = nco_cln_fmt_dt(&tm, ifmt);
+
+    }
+  }
+  else if(var->type==NC_FLOAT){
+
+    float mss_val_flt;
+    if(var->has_mss_val)
+       mss_val_flt=var->mss_val.fp[0];
+
+    for (idx = 0; idx < sz; idx++) {
+
+      if(var->has_mss_val && var->val.fp[idx]==mss_val_flt ){
+        var_ret->val.sngp[idx] = strdup(empty_sng);
+        continue;
+      }
+
+
+      tm.value = (double) (var->val.fp[idx]);
+
+      if (lmt_cln == cln_360 || lmt_cln == cln_365 || lmt_cln == cln_366)
+        nco_cln_pop_tm(&tm);
+      else
+        (void) ut_decode_time(tm.value, &tm.year, &tm.month, &tm.day, &tm.hour, &tm.min, &tm.sec, &resolution);
+
+      var_ret->val.sngp[idx] = nco_cln_fmt_dt(&tm, ifmt);
+
+    }
+
+  }
+
+
+  cast_nctype_void(var->type,&var->val);
+  cast_nctype_void(var_ret->type,&var->val);
+
+    return NCO_NOERR;
+
+} /* end nco_cln_var_prs() */
+
+
+
+
+
 # endif /* HAVE_UDUNITS2_H */
 #endif /* ENABLE_UDUNITS */
 /* End UDUnits-related routines*/
