@@ -2,7 +2,7 @@
 
 /* Purpose: String utilities */
 
-/* Copyright (C) 1995--2016 Charlie Zender
+/* Copyright (C) 1995--2017 Charlie Zender
    This file is part of NCO, the netCDF Operators. NCO is free software.
    You may redistribute and/or modify NCO under the terms of the 
    GNU General Public License (GPL) Version 3 with exceptions described in the LICENSE file */
@@ -263,6 +263,8 @@ nm2sng_cdl /* [fnc] Turn variable/dimension/attribute name into legal CDL */
   while(*chr_in_ptr){
     if(isascii(*chr_in_ptr)){
       if(iscntrl(*chr_in_ptr)){	/* Render control chars as two hex digits, \%xx */
+	/* 20170810: GCC7.x produces -Wformat-truncation warning here, that 4 B destination is too small
+	   False-positive warning? How to eliminate? */
 	snprintf(chr_out_ptr,4,"\\%%%.2x",*chr_in_ptr);
 	chr_out_ptr+=4;
       }else{
@@ -342,12 +344,9 @@ nm2sng_jsn /* [fnc] Turn variable/dimension/attribute name into legal CDL */
   chr_out_ptr[0]='\0';
 
   /* Search and replace special characters */
-  while(*chr_in_ptr)
-  {
-    if(iscntrl(*chr_in_ptr))
-    { 
-      switch(*chr_in_ptr)
-      {    
+  while(*chr_in_ptr){
+    if(iscntrl(*chr_in_ptr)){ 
+      switch(*chr_in_ptr){    
          case '\b':
          case '\f':
          case '\n':
@@ -355,24 +354,22 @@ nm2sng_jsn /* [fnc] Turn variable/dimension/attribute name into legal CDL */
          case '\t': 
          case '\\': 
          case '\"': 
-	 /* according to json spec control char  '/' should be escaped bu this is mangles filepaths so leave it out for now */
+	 /* According to json spec control char  '/' should be escaped but this is mangles filepaths so leave it out for now */
          /* case '\/': */
-         case '\0':	
+         case '\0':
            *chr_out_ptr++='\\';
 	   *chr_out_ptr++=*chr_in_ptr;
 	   break;
          default: 
             /* ignore other control chars */
       	  break;
-      }
-    }
-    else
-    {
+      } /* !switch */
+    }else{ /* !iscntrl() */
       *chr_out_ptr++=*chr_in_ptr;
-    }
+    } /* !iscntrl() */
     /* Advance character */
     chr_in_ptr++;
-  }      
+  } /* !while() */
   /* NUL-terminate */
   *chr_out_ptr='\0';
 
@@ -382,8 +379,6 @@ nm2sng_jsn /* [fnc] Turn variable/dimension/attribute name into legal CDL */
   return nm_jsn;
 } /* end nm2sng_jsn() */
 
-
-
 char * /* O [sng] CDL-compatible name */
 nm2sng_fl /* [fnc] Turn file name into legal string for shell commands */
 (const char * const nm_sng) /* I [sng] Name to sanitize */
@@ -423,6 +418,8 @@ nm2sng_fl /* [fnc] Turn file name into legal string for shell commands */
   while(*chr_in_ptr){
     if(isascii(*chr_in_ptr)){
       if(iscntrl(*chr_in_ptr)){	/* Render control chars as two hex digits, \%xx */
+	/* 20170810: GCC7.x produces -Wformat-truncation warning here, that 4 B destination is too small 
+	   False-positive warning? How to eliminate? */
 	snprintf(chr_out_ptr,4,"\\%%%.2x",*chr_in_ptr);
 	chr_out_ptr+=4;
       }else{
@@ -622,6 +619,9 @@ sng_ascii_trn /* [fnc] Replace C language '\X' escape codes in string with ASCII
       (void)fprintf(stderr,"%s: WARNING C language escape code %.2s found in string, not translating to NUL since this would make the subsequent portion of the string invisible to all C Standard Library string functions\n",nco_prg_nm_get(),backslash_ptr); 
       trn_flg=False;
       /* 20101013: Tried changing above behavior to following, and it opened a Hornet's nest of problems... */
+      /* 20170221: Use-case where translating "\0" to NUL would be helpful is when user needs to pad netCDF3 character
+	 array value to size of underlying dimension, and have user-specified value NUL-terminated short of full 
+	 dimension size */
       /* *backslash_ptr='\0'; *//* 000   0     00    NUL '\0' */
       /*      (void)fprintf(stderr,"%s: WARNING translating C language escape code \"\\0\" found in user-supplied string to NUL. This will make the subsequent portion of the string, if any, invisible to C Standard Library string functions. And that may cause unintended consequences.\n",nco_prg_nm_get());*/
       break;
@@ -632,7 +632,7 @@ sng_ascii_trn /* [fnc] Replace C language '\X' escape codes in string with ASCII
     } /* end switch */
     if(trn_flg){
       /* Remove character after backslash character */
-      (void)memmove(backslash_ptr+1,backslash_ptr+2,(strlen(backslash_ptr+2)+1)*sizeof(char));
+      (void)memmove(backslash_ptr+1,backslash_ptr+2,(strlen(backslash_ptr+2)+1L)*sizeof(char));
       /* Count translations performed */
       trn_nbr++;
     } /* end if */
