@@ -2,7 +2,7 @@
 
 /* Purpose: String utilities */
 
-/* Copyright (C) 1995--2016 Charlie Zender
+/* Copyright (C) 1995--2017 Charlie Zender
    This file is part of NCO, the netCDF Operators. NCO is free software.
    You may redistribute and/or modify NCO under the terms of the 
    GNU General Public License (GPL) Version 3 with exceptions described in the LICENSE file */
@@ -25,6 +25,7 @@
 #endif /* !HAVE_STRINGS_H */
 
 #ifdef _MSC_VER
+# define NEED_STRSEP
 # define NEED_STRCASECMP
 # define NEED_STRCASESTR
 #endif /* !_MSC_VER */
@@ -77,12 +78,12 @@ extern "C" {
   
   /* 20130827 GNU g++ always provides strcasestr(), MSVC never does */
 #ifndef __GNUG__
-# ifdef NEED_STRCASESTR
+  //# ifdef NEED_STRCASESTR
   char * /* O [sng] Pointer to sng_2 in sng_1 */
   strcasestr /* [fnc] Lexicographical case-insensitive string search */
   (const char * const sng_1, /* I [sng] First string */
    const char * const sng_2); /* I [sng] Second string */
-# endif /* !NEED_STRCASESTR */
+  //# endif /* !NEED_STRCASESTR */
 #endif /* __GNUG__ */
   
 #ifdef NEED_STRDUP
